Misc: Revert all references to libusb/libusb.info
diff --git a/examples/dpfp.c b/examples/dpfp.c
index 3f41e0e..ed68267 100644
--- a/examples/dpfp.c
+++ b/examples/dpfp.c
@@ -1,5 +1,5 @@
 /*
- * libusbx example program to manipulate U.are.U 4000B fingerprint scanner.
+ * libusb example program to manipulate U.are.U 4000B fingerprint scanner.
  * Copyright © 2007 Daniel Drake <dsd@gentoo.org>
  *
  * Basic image capture program only, does not consider the powerup quirks or
diff --git a/examples/dpfp_threaded.c b/examples/dpfp_threaded.c
index 6970dac..771e2ec 100644
--- a/examples/dpfp_threaded.c
+++ b/examples/dpfp_threaded.c
@@ -1,5 +1,5 @@
 /*
- * libusbx example program to manipulate U.are.U 4000B fingerprint scanner.
+ * libusb example program to manipulate U.are.U 4000B fingerprint scanner.
  * Copyright © 2007 Daniel Drake <dsd@gentoo.org>
  *
  * Basic image capture program only, does not consider the powerup quirks or
diff --git a/examples/listdevs.c b/examples/listdevs.c
index 31ad26e..3328910 100644
--- a/examples/listdevs.c
+++ b/examples/listdevs.c
@@ -1,5 +1,5 @@
 /*
- * libusbx example program to list devices on the bus
+ * libusb example program to list devices on the bus
  * Copyright © 2007 Daniel Drake <dsd@gentoo.org>
  *
  * This library is free software; you can redistribute it and/or
diff --git a/examples/ezusb.c b/examples/ezusb.c
index 278af5d..5111f98 100644
--- a/examples/ezusb.c
+++ b/examples/ezusb.c
@@ -181,7 +181,7 @@
 		RW_INTERNAL, addr & 0xFFFF, addr >> 16,
 		&data, 1, 1000);
 	if ((status != 1) &&
 		/* We may get an I/O error from libusbx as the device disappears */
 		((!doRun) || (status != LIBUSB_ERROR_IO)))
 	{
 		const char *mesg = "can't modify CPUCS";
@@ -208,7 +208,7 @@
 		LIBUSB_ENDPOINT_OUT | LIBUSB_REQUEST_TYPE_VENDOR | LIBUSB_RECIPIENT_DEVICE,
 		RW_INTERNAL, addr & 0xFFFF, addr >> 16,
 		NULL, 0, 1000);
 	/* We may get an I/O error from libusbx as the device disappears */
 	if ((status != 0) && (status != LIBUSB_ERROR_IO))
 	{
 		const char *mesg = "failed to send jump command";
@@ -457,7 +457,7 @@
 		data_addr = (block_header[2] << 8) + block_header[3];
 		if (data_len > sizeof(data)) {
 			/* If this is ever reported as an error, switch to using malloc/realloc */
-			logerror("IIC data block too small - please report this error to libusbx.org\n");
+			logerror("IIC data block too small - please report this error to libusb.info\n");
 			return -1;
 		}
 		read_len = fread(data, 1, data_len, image);
@@ -699,7 +699,7 @@
 }
 
 /*
  * Load a firmware file into target RAM. device is the open libusbx
  * device, and the path is the name of the source file. Open the file,
  * parse the bytes, and write them in one or two phases.
  *
@@ -181,7 +181,7 @@
 		&data, 1, 1000);
 	if ((status != 1) &&
-		/* We may get an I/O error from libusbx as the device disappears */
+		/* We may get an I/O error from libusb as the device disappears */
 		((!doRun) || (status != LIBUSB_ERROR_IO)))
 	{
@@ -208,7 +208,7 @@
 		RW_INTERNAL, addr & 0xFFFF, addr >> 16,
 		NULL, 0, 1000);
-	/* We may get an I/O error from libusbx as the device disappears */
+	/* We may get an I/O error from libusb as the device disappears */
 	if ((status != 0) && (status != LIBUSB_ERROR_IO))
 	{
@@ -699,7 +699,7 @@
 
 /*
- * Load a firmware file into target RAM. device is the open libusbx
+ * Load a firmware file into target RAM. device is the open libusb
  * device, and the path is the name of the source file. Open the file,
  * parse the bytes, and write them in one or two phases.
diff --git a/examples/fxload.c b/examples/fxload.c
index 14226ca..9f0d554 100644
--- a/examples/fxload.c
+++ b/examples/fxload.c
@@ -40,7 +40,7 @@
 #endif
 
 #ifndef FXLOAD_VERSION
-#define FXLOAD_VERSION (__DATE__ " (libusbx)")
+#define FXLOAD_VERSION (__DATE__ " (libusb)")
 #endif
 
 #ifndef ARRAYSIZE
@@ -69,7 +69,7 @@
 	fprintf(stderr, "  -i <path>       -- Firmware to upload\n");
 	fprintf(stderr, "  -t <type>       -- Target type: an21, fx, fx2, fx2lp, fx3\n");
 	fprintf(stderr, "  -d <vid:pid>    -- Target device, as an USB VID:PID\n");
-	fprintf(stderr, "  -p <bus,addr>   -- Target device, as a libusbx bus number and device address path\n");
+	fprintf(stderr, "  -p <bus,addr>   -- Target device, as a libusb bus number and device address path\n");
 	fprintf(stderr, "  -v              -- Increase verbosity\n");
 	fprintf(stderr, "  -q              -- Decrease verbosity (silent mode)\n");
 	fprintf(stderr, "  -V              -- Print program version\n");
@@ -165,7 +165,7 @@
 		}
 	}
 
 	/* open the device using libusbx */
 	status = libusb_init(NULL);
 	if (status < 0) {
 		logerror("libusb_init() failed: %s\n", libusb_error_name(status));
@@ -165,7 +165,7 @@
 	}
 
-	/* open the device using libusbx */
+	/* open the device using libusb */
 	status = libusb_init(NULL);
 	if (status < 0) {
diff --git a/examples/xusb.c b/examples/xusb.c
index 56386df..77c8c46 100644
--- a/examples/xusb.c
+++ b/examples/xusb.c
@@ -43,7 +43,7 @@
 #define false (!true)
 #endif
 
 // Future versions of libusbx will use usb_interface instead of interface
 // in libusb_config_descriptor => catter for that
 #define usb_interface interface
 
@@ -1089,7 +1089,7 @@
 	}
 
 	version = libusb_get_version();
-	printf("Using libusbx v%d.%d.%d.%d\n\n", version->major, version->minor, version->micro, version->nano);
+	printf("Using libusb v%d.%d.%d.%d\n\n", version->major, version->minor, version->micro, version->nano);
 	r = libusb_init(NULL);
 	if (r < 0)
 		return r;
@@ -43,7 +43,7 @@
 #endif
 
-// Future versions of libusbx will use usb_interface instead of interface
+// Future versions of libusb will use usb_interface instead of interface
 // in libusb_config_descriptor => catter for that
 #define usb_interface interface